from tensorflow.python.keras.utils import data_utils
import json

CLASS_INDEX = None
CLASS_INDEX_PATH = ('https://raw.githubusercontent.com/gWOLF3/amerikana/master/imagenet_class_index.json')

def decode_predictions(preds, top=5):
  """Decodes the prediction of an ImageNet model.
  Arguments:
    preds: Numpy array encoding a batch of predictions.
    top: Integer, how many top-guesses to return. Defaults to 5.
  Returns:
    A list of lists of top class prediction tuples
    `(class_name, class_description, score)`.
    One list of tuples per sample in batch input.
  Raises:
    ValueError: In case of invalid shape of the `pred` array
      (must be 2D).
  """
  global CLASS_INDEX

  if len(preds.shape) != 2 or preds.shape[1] != 1000:
    raise ValueError('`decode_predictions` expects '
                     'a batch of predictions '
                     '(i.e. a 2D array of shape (samples, 1000)). '
                     'Found array with shape: ' + str(preds.shape))
  if CLASS_INDEX is None:
    fpath = data_utils.get_file(
        'imagenet_class_index_simple.json',
        CLASS_INDEX_PATH,
        cache_subdir='models',
        file_hash='9906722f13787170d0ba60270331a169')
    with open(fpath) as f:
      CLASS_INDEX = json.load(f)
  results = []
  for pred in preds:
    top_indices = pred.argsort()[-top:][::-1]
    result = [tuple(CLASS_INDEX[str(i)]) + (pred[i],) for i in top_indices]
    result.sort(key=lambda x: x[2], reverse=True)
    results.append(result)
  return results




from distutils.core import setup
setup(
  name = 'amerikana',         
  packages = ['amerikana'],  
  version = '0.2',      
  license='MIT',       
  description = '☕ a simpler imagenet class synset and decoder utility. pluggable and 100% tf.keras compatible',
   
  author = 'Glenn Wolfe',
  author_email = 'glennwolfe@protonmail.com',
  url = 'https://github.com/gWOLF3/amerikana',
  download_url = 'https://github.com/gWOLF3/amerikana/archive/0.2.tar.gz',
  keywords = ['keras', 'imagenet', 'labels', 'simple', 'american'], 
  install_requires=[           
          'tensorflow'
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
